# from eseas import Options, Seasonal
# from pathlib import Path


# def test_crunch(capsys):
#     with capsys.disabled():

#         fold = "unix"
#         demetra_folder = rf"./eseas/data_for_testing/{fold}"
#         # java_folder = r"../jwsacruncher-2.2.4/bin"
#         java_folder = Path(r"../../Downloads/jwsacruncher-2.2.4/bin")
#         local_folder = r"./eseas_output"
