"""
----------------------------------
      Global options
----------------------------------
"""

"""
    middle_folder
    .............
      -middle_folder : 'test_output'
      local_w_space / middle_folder / ...
      # produced csv content will be placed here
"""
middle_folder = "test_output"
"""
    demetra_command_file_name
    .............
       e.g. :  demetra_commands
"""
demetra_command_file_name = "demetra_commands"
"""
    max_num
    ...............
      this number will be maximum number of xml files that can be picked
      while searching for demetra xml files.
"""
max_num = 5_000
